@@ -11,6 +11,18 @@ def upload_file_old(path):
     public_folder_id = "1kl75TP6zJiuFBdjhJUw1GHhdcIEjueoE"
     file_name = os.path.basename(path)
     return Client("/u02/drive_config/public_config/coca_idrive.json", "upload", path, "").upload_file(file_name, path, public_folder_id)
+def upload_static_file(path):
+    url = "http://api-magicframe.automusic.win/resource-static/upload"
+    payload = {}
+    files = [
+        ('file_input', (os.path.basename(path),
+                        open(path, 'rb'),
+                        'image/jpeg'))
+    ]
+    headers = {}
+    return requests.request("POST", url, headers=headers, data=payload, files=files).json()
+
+
 def upload_file(path):
     dh = DriverHelper()
     x = dh.upload_file_auto("studio-result", [path])
