@@ -119,7 +119,7 @@ def create_video(list_comp_data, path_video, job_id, mf_server):
     is_mix_lyric=False
     #check if videos are compilation
     for comp in arr_comps:
-        if indexVidBG < 5 and  (comp.type == "image"):
+        if indexVidBG < 5 and  (comp.type == "image" or comp.type == "video"):
             firstImageOrVideoBG.append(comp.make())
             indexVidBG+=1
 
