@@ -21,15 +21,29 @@ def download_audio(url, ext='mp3', retries= 3):
             raise
         return download_audio(url, ext, retries-1)
     return rs
-def create_lyric_outro_songs(deezer_artist_id, lyric_outro_repeat, retries=3):
+def create_lyric_outro_songs(deezer_artist_id, lyric_outro_repeat, outro_claim_topic, retries=3):
     if deezer_artist_id == 977996688:
         return None
+    song_claim_url=None
+    if outro_claim_topic:
+        try:
+            res_claim = requests.get(f"http://automusic.win/api/claim/music?topic={outro_claim_topic}&number=1").json()
+            if len(res_claim)>0:
+                jclaim=res_claim[0]
+                song_claim_url=jclaim['local_link']
+        except:
+            pass
     res = requests.get(f"http://source.automusic.win/deezer/artist/preview/{deezer_artist_id}/{lyric_outro_repeat}").json()
     arr_song=[]
     file_merg_path = os.path.join(get_dir('coolbg_ffmpeg'), str(uuid.uuid4()))
     file_merg = open(file_merg_path, "a")
     final_clip_path = os.path.join(get_dir('coolbg_ffmpeg'), str(uuid.uuid4()) + '-final.mp3')
+    cnt=0
     for item in res:
+        is_fade_claim=False
+        if cnt==1 and song_claim_url:
+            item=song_claim_url
+            is_fade_claim=True
         tmp = download_file(item, ext='mp3')
         try:
             audio_test = AudioFileClip(tmp)
@@ -41,9 +55,13 @@ def create_lyric_outro_songs(deezer_artist_id, lyric_outro_repeat, retries=3):
             continue
             pass
         tmp = normal_audio(tmp)
-        tmp = fade_audio(tmp)
+        fade_dur=30
+        if is_fade_claim:
+            fade_dur=int(audioduration)
+        tmp = fade_audio(tmp, dur=fade_dur)
         arr_song.append(tmp)
         file_merg.write("file '%s'\n" % tmp)
+        cnt+=1
     file_merg.close()
     if retries>0 and len(arr_song) != lyric_outro_repeat:
         retries-=1
